# Bot Adversarial Dialogue Dataset.

Dialogue datasets labeled with offensiveness from Bot Adversarial Dialogue task.
The dialogues were collected by asking humans to adversarially talk to bots.


More details in the [paper](https://arxiv.org/abs/2010.07079).
